<p align="center">
  <img src="https://github.com/k2sebeom/pyplayscii/blob/master/src/img/PlayScii.png" width=700 height=200>
</p>

------

## Description
PyPlayScii is a Python package that enables an simple object oriented implementation of ascii art games. By asigning the shapes of the game objects by texts seprated by newline characters and determining what to do every frame, you can quickly implement an ascii art game which can be run directly on terminal window. The following shows an example of an ascii art game implemented by PyPlayScii.



## Features


